Django-Crashlog
---------------

Ispired by django-db-log (https://github.com/dcramer/django-db-log),
intended to be used for small apps/local development.

Use Sentry (https://github.com/getsentry/sentry) for serious error logging.



